NECallParam class

Parameters used when placing a call.

Annotations
  • @JsonSerializable.new()

Constructors

NECallParam({required String accId, String? extraInfo, String? rtcChannelName, String? globalExtraCopy, required NECallType callType, NECallPushConfig? pushConfig})
NECallParam.fromJson(Map<String, dynamic> json)
factory

Properties

accId String
final
callType NECallType
final
extraInfo String?
final
globalExtraCopy String?
final
hashCode int
The hash code for this object.
no setterinherited
pushConfig NECallPushConfig?
final
rtcChannelName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited