NECallTypeChangeInfo class

Information describing a call type change event.

Annotations
  • @JsonSerializable.new()

Constructors

NECallTypeChangeInfo({required NECallType callType, required NECallSwitchState state})
NECallTypeChangeInfo.fromJson(Map<String, dynamic> json)
factory

Properties

callType NECallType
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state NECallSwitchState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited