NEGroupCallParam class
发起群呼参数
Constructors
-
NEGroupCallParam({String? callId, required List<
String?> calleeList, String? groupId, required int groupType, int? inviteMode, int? joinMode, String? extraInfo, NEGroupPushParam? pushParam})
Properties
-
calleeList
↔ List<
String?> -
getter/setter pair
- callId ↔ String?
-
getter/setter pair
- extraInfo ↔ String?
-
getter/setter pair
- groupId ↔ String?
-
getter/setter pair
- groupType ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviteMode ↔ int?
-
getter/setter pair
- joinMode ↔ int?
-
getter/setter pair
- pushParam ↔ NEGroupPushParam?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → NEGroupCallParam