NEGroupJoinMode class abstract
加入模式常量
控制如何加入群呼。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- EVERYONE → const int
- 每个人都能主动加入此多人通话(默认)
- ONLY_BE_INVITED → const int
- 不能主动加入,需要被动邀请