NEGroupJoinResult class
加入群呼结果
- Inheritance
-
- Object
- NEGroupResult
- NEGroupJoinResult
Constructors
- NEGroupJoinResult({required int code, String? msg, NEGroupCallInfo? callInfo})
-
const
- NEGroupJoinResult.fromPigeon(GroupJoinResponse response)
-
从 Pigeon 响应创建
factory
Properties
- callInfo → NEGroupCallInfo?
-
群呼信息
final
- code → int
-
响应码 (0=成功)
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
是否成功
no setterinherited
- msg → String?
-
消息
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited